@@ -26,6 +26,9 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 后台DB执行错误。
 DBERROR = 'DBError'
 
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 访问基础网络服务失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_BASENETWORKACCESSERROR = 'FailedOperation.BaseNetworkAccessError'
 
@@ -47,6 +50,9 @@ FAILEDOPERATION_CAMSIGANDAUTHERROR = 'FailedOperation.CamSigAndAuthError'
 # 获取项目信息失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_CDBCGWCONNECTERROR = 'FailedOperation.CdbCgwConnectError'
 
+# 不支持新增基础网络。
+FAILEDOPERATION_CREATEBASICNETWORKDENIEDERROR = 'FailedOperation.CreateBasicNetworkDeniedError'
+
 # 创建续费订单失败。
 FAILEDOPERATION_CREATEORDERFAILED = 'FailedOperation.CreateOrderFailed'
 
@@ -56,6 +62,9 @@ FAILEDOPERATION_DATABASEACCESSERROR = 'FailedOperation.DatabaseAccessError'
 # VPC删除路由失败。
 FAILEDOPERATION_DELETEALLROUTE = 'FailedOperation.DeleteAllRoute'
 
+# 资源解绑项目失败。
+FAILEDOPERATION_DELETERESOURCEPROJECTTAGERROR = 'FailedOperation.DeleteResourceProjectTagError'
+
 # ES访问失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_ESCONNECTERROR = 'FailedOperation.ESConnectError'
 
@@ -359,6 +368,12 @@ INVALIDPARAMETERVALUE_PARAMETERHANDLEERROR = 'InvalidParameterValue.ParameterHan
 # 参数长度超过限制。
 INVALIDPARAMETERVALUE_PARAMETERLENGTHLIMITERROR = 'InvalidParameterValue.ParameterLengthLimitError'
 
+# 存在无效的参数值。
+INVALIDPARAMETERVALUE_PARAMETEROUTRANGEERROR = 'InvalidParameterValue.ParameterOutRangeError'
+
+# 参数值超过上限。
+INVALIDPARAMETERVALUE_PARAMETERVALUEEXCEEDERROR = 'InvalidParameterValue.ParameterValueExceedError'
+
 # 只读实例组不存在。
 INVALIDPARAMETERVALUE_READONLYGROUPNOTEXIST = 'InvalidParameterValue.ReadOnlyGroupNotExist'
 
